==> plasma-mediacenter-0.8.90.tar.bz2: plasma-mediacenter/browsingbackends/localfiles/localmusic/localmusicbackend.cpp <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "localmusicbackend.h"
#include "localmusicmodel.h"

MEDIACENTER_EXPORT_BROWSINGBACKEND(LocalMusicBackend)

LocalMusicBackend::LocalMusicBackend (QObject* parent, const QVariantList& args)
    : LocalFilesAbstractBackend (parent, args)
{

}

LocalMusicBackend::~LocalMusicBackend()
{}

void LocalMusicBackend::initModel()
{
    setModel(new LocalMusicModel(this));
}

==> plasma-mediacenter-1.0.95.tar.bz2: plasma-mediacenter/browsingbackends/localfiles/localmusic/localmusicbackend.cpp <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "localmusicbackend.h"
#include "localmusicmodel.h"

MEDIACENTER_EXPORT_BROWSINGBACKEND(LocalMusicBackend)

LocalMusicBackend::LocalMusicBackend (QObject* parent, const QVariantList& args)
    : LocalFilesAbstractBackend (parent, args)
    , m_model(0)
{

}

LocalMusicBackend::~LocalMusicBackend()
{}

void LocalMusicBackend::initModel()
{
    if (!m_model) {
        m_model = new LocalMusicModel(this);
    }
    setModel(m_model);
}
